
## CATO-CLI - mutation.site.removeBgpPeer:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeBgpPeer) for documentation on this operation.

### Usage for mutation.site.removeBgpPeer:

`catocli mutation site removeBgpPeer -h`

`catocli mutation site removeBgpPeer <json>`

`catocli mutation site removeBgpPeer "$(cat < removeBgpPeer.json)"`

`catocli mutation site removeBgpPeer '{"removeBgpPeerInput": {"id": {"id": "ID"}}}'`

#### Operation Arguments for mutation.site.removeBgpPeer ####
`accountId` [ID] - (required) N/A 
`removeBgpPeerInput` [RemoveBgpPeerInput] - (required) N/A 
